@@ -759,10 +759,17 @@ sub create_item {
   }
   $self->add_item($name, $item);
 
+  my $before_fix = np($item);
   $self->fix_columns($name, $item);
+  my $after_fix = np($item);
 
   # Don't keep going if we have already satisfy all UKs
   my $row = $self->find_by_unique_constraints($name, $item);
+  if ($row && $ENV{SIMS_DEBUG}) {
+    warn "Found duplicate in $name:\n"
+      . "\tbefore fix_columns (".np($before_fix).")\n"
+      . "\tafter fix_columns (".np($after_fix).")\n";
+  }
 
   my $source = $self->schema->source($name);
   $self->{hooks}{preprocess}->($name, $source, $item);
@@ -816,7 +823,17 @@ sub run {
           if ($self->{allow_pk_set_value}) {
             set_allow_pk_to($item, 1);
           }
-          my $row = $self->create_item($name, $item);
+
+          my $row = do {
+            no strict;
+
+            # DateTime objects print too big in SIMS_DEBUG mode, so provide a
+            # good way for DDP to print them nicely.
+            local *{'DateTime::_data_printer'} = sub { shift->iso8601 }
+              unless DateTime->can('_data_printer');
+
+            $self->create_item($name, $item);
+          };
 
           if ($self->{initial_spec}{$name}{$item}) {
             push @{$self->{rows}{$name} //= []}, $row;
